#ifndef MAINWINDOW_H
#define MAINWINDOW_H
#include <QDialog>
#include <QSettings>
#include <QFile>
#include <QDoubleSpinBox>
#include <QMessageBox>
#include <QTextStream>
#include <QtCore>
#include <QMainWindow>
#include <QLocale>
#include <QProcess>

namespace Ui {
    class mainwindow;
}

class mainwindow : public QDialog
{
    Q_OBJECT

public:
    explicit mainwindow(QWidget *parent = 0);
    ~mainwindow();
    void readvalues();
    void storevalues();
    void sed(QString speed, QString path);
    QString abouttext;
    QString abouttitle;

private:
    Ui::mainwindow *ui;

private slots:
    void orientationChanged();
    void on_buttonBox_clicked(QAbstractButton* button);
};

#endif // MAINWINDOW_H
